@@ -203,11 +203,13 @@ void music()
 {
   int x, i, k;
   int consolefd = 0;
+  char *disp;
 
   /* If we're in X, we have to explicitly use the console */
   if (strncmp(getenv("TERM"), "xterm", 5) == 0 &&
-	(strcmp(getenv("DISPLAY"), ":0.0") == 0 ||
-	(strcmp(getenv("DISPLAY"), ":0") == 0))) {
+	(disp = getenv("DISPLAY")) != NULL &&
+	(strcmp(disp, ":0.0") == 0 ||
+	(strcmp(disp, ":0") == 0))) {
 	consolefd = open("/dev/console", O_WRONLY);
 	if (consolefd < 0) consolefd = 0;
   }
@@ -703,17 +705,21 @@ static void writedialdir()
   FILE *fp;
   struct dver dial_ver;
   char oldfl;
+  int omask;
 
   /* Make no sense if access denied */
   if (dendd) return;
 
   sprintf(dfile, "%s/.dialdir", homedir);
 
+  omask = umask(077);
   if ((fp = sfopen(dfile, "w")) == (FILE *)0) {
+	(void)umask(omask);
   	werror("Can't write to ~/.dialdir");
 	dendd = 1;
   	return;
   }
+  (void)umask(omask);
 
   d = dialents;
   /* Set up version info. */
